@@ -1,25 +1,14 @@
 /*
-   This file is part of the KDE libraries
-   Copyright (c) 2011 David Faure <faure@kde.org>
+    This file is part of the KDE libraries
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2.1 as published by the Free Software Foundation.
+    SPDX-FileCopyrightText: 2011 David Faure <faure@kde.org>
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.1-only
 */
 
 #include "kfilesystemtype.h"
 #include <QFile>
-#include <QDebug>
+#include "kcoreaddons_debug.h"
 //#include <errno.h>
 
 #ifndef Q_OS_WIN
@@ -96,7 +85,6 @@ static KFileSystemType::Type determineFileSystemTypeImpl(const QByteArray &path)
 {
     struct statfs buf;
     if (statfs(path.constData(), &buf) != 0) {
-        //qDebug() << path << errno << strerror(errno);
         return KFileSystemType::Unknown;
     }
     switch (static_cast<unsigned long>(buf.f_type)) {
