@@ -27,10 +27,7 @@ KPluginFactory::KPluginFactory(KPluginFactoryPrivate &d)
     factorycleanup()->add(this);
 }
 
-KPluginFactory::~KPluginFactory()
-{
-    delete d_ptr;
-}
+KPluginFactory::~KPluginFactory() = default;
 
 KPluginMetaData KPluginFactory::metaData() const
 {
@@ -205,7 +202,7 @@ QObject *KPluginFactory::create(const char *iface, QWidget *parentWidget, QObjec
     }
 
     if (obj) {
-        emit objectCreated(obj);
+        Q_EMIT objectCreated(obj);
     }
     return obj;
 }
